# subjective-logic

A subjective logic implementaion in python

## Install

```bash
python -m pip install subjective-logic --force-reinstall
```

### Developer Install

```bash
pip install -e .
```

## Tests

To test the code base, simply run tox from the root directory of your project:

```bash
pip install -e .[dev]
tox
```

## References

Audun Jøsang. “Categories of Belief Fusion”. In: _Journal of Advances in Information Fusion_ 13.2 (2018), pp. 235–254.

Audun  Jøsang. _Subjective  Logic  -  A  Formalism  for  Reasoning  Under  Uncertainty_. Artificial Intelligence: Foundations, Theory, and Algorithms. Springer, 2016
